==> nextcloud-27.1.4.tgz: nextcloud/apps/federation/l10n/es_EC.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Agregado a la lista de servidores de confianza",
    "Server is already in the list of trusted servers." : "El servidor ya se encuentra en la lista de servidores de confianza.",
    "No server to federate with found" : "No se encontraron servidores para integrar a la federación",
    "Could not add server" : "No fue posible agregar el servidor",
    "Trusted servers" : "Servidores de confianza",
    "Federation" : "Federación",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "La federación te permite conectarte con otros servidores de confianza para intercambiar el directorio de usuarios.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "La federación te permite conectarte con otros servidores de confianza para intercambiar el directorio de usuarios. Por ejemplo, esto se usará para auto-completar usuarios externos en el recurso compartido federado.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "La federación te permite conectarte con otros servidores de confianza para intercambiar el directorio de usuarios. Por ejemplo, esto se utiliza para autocompletar usuarios externos en el uso compartido federado. No es necesario agregar un servidor como servidor de confianza para crear un uso compartido federado.",
    "+ Add trusted server" : "+ Agregar servidor de confianza",
    "Trusted server" : "Servidor de confianza",
    "Add" : "Agregar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-28.0.3.tgz: nextcloud/apps/federation/l10n/es_EC.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Agregado a la lista de servidores de confianza",
    "Server is already in the list of trusted servers." : "El servidor ya se encuentra en la lista de servidores de confianza.",
    "No server to federate with found" : "No se encontraron servidores para integrar a la federación",
    "Could not add server" : "No fue posible agregar el servidor",
    "Trusted servers" : "Servidores de confianza",
    "Federation" : "Federación",
    "+ Add trusted server" : "+ Agregar servidor de confianza",
    "Trusted server" : "Servidor de confianza",
    "Add" : "Agregar",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "La federación te permite conectarte con otros servidores de confianza para intercambiar el directorio de usuarios.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "La federación te permite conectarte con otros servidores de confianza para intercambiar el directorio de usuarios. Por ejemplo, esto se usará para auto-completar usuarios externos en el recurso compartido federado.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "La federación te permite conectarte con otros servidores de confianza para intercambiar el directorio de usuarios. Por ejemplo, esto se utiliza para autocompletar usuarios externos en el uso compartido federado. No es necesario agregar un servidor como servidor de confianza para crear un uso compartido federado."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
